@@ -28,6 +28,7 @@ class Producer:
         self.sqs_client = None
         self.app = None
         self.sign = ''
+        self.log_app_name = ''
 
     def __format_msg(self, msg):
         if isinstance(msg, (str, int, bool, float)):
@@ -35,8 +36,9 @@ class Producer:
         else:
             return orjson.dumps(msg)
 
-    def start(self, app: flask.app.Flask, max_pool_connections=50, max_attempts=3):
+    def start(self, app: flask.app.Flask, log_app_name, max_pool_connections=50, max_attempts=3):
         self.app = app
+        self.log_app_name = log_app_name
 
         if self.started:
             return
@@ -119,9 +121,10 @@ class Producer:
         msg_body['send_success_time'] = send_success_time
         msg_body['msg_id'] = msg_id
 
-        producer_log_len = redis_store.lpush(ConsumerLogConstants.PUB_LOG, json.dumps(msg_body))
+        redis_pub_log_key = ConsumerLogConstants.PUB_LOG.format(self.log_app_name)
+        producer_log_len = redis_store.lpush(redis_pub_log_key, json.dumps(msg_body))
         if producer_log_len >= ConsumerLogConstants.CONSUMER_LOG_MAX_SLEEP_ES_BULK_BUFFER_SIZE:
-            redis_store.rpop(ConsumerLogConstants.PUB_LOG)
+            redis_store.rpop(redis_pub_log_key)
             return
         # 计算是否可以进行保存
         can_bulk_save = producer_log_len % ConsumerLogConstants.CONSUMER_LOG_ES_BULK_NUM == 0
